"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DesktopNotification = exports.terminateNotifications = exports.initializeNotifications = exports.supportsNotifications = void 0;
const uuid_1 = require("uuid");
const LRUCache = require("lru-cache");
const os = require("os");
function supportsNotifications() {
    if (process.platform !== 'win32') {
        return false;
    }
    const versionComponents = os.release().split('.');
    const majorVersion = parseInt(versionComponents[0], 10);
    // Only Windows 10 and newer are supported
    return majorVersion >= 10;
}
exports.supportsNotifications = supportsNotifications;
// Windows-only for now
const nativeModule = supportsNotifications()
    ? require('../../build/Release/desktop-notifications.node')
    : null;
function initializeNotifications(toastActivatorClsid) {
    nativeModule === null || nativeModule === void 0 ? void 0 : nativeModule.initializeNotifications(toastActivatorClsid, onNotificationEvent);
}
exports.initializeNotifications = initializeNotifications;
function terminateNotifications() {
    nativeModule === null || nativeModule === void 0 ? void 0 : nativeModule.terminateNotifications();
}
exports.terminateNotifications = terminateNotifications;
function showNotification(id, title, body) {
    var _a;
    return (_a = nativeModule === null || nativeModule === void 0 ? void 0 : nativeModule.showNotification(id, title, body)) !== null && _a !== void 0 ? _a : null;
}
function closeNotification(id) {
    if (!nativeModule) {
        // this code is a no-op when the module is missing
        return;
    }
    return nativeModule.closeNotification(id);
}
const shownNotifications = new LRUCache({
    max: 50,
});
function onNotificationEvent(event, id) {
    var _a;
    const notification = shownNotifications.get(id);
    if (notification === undefined) {
        // TODO: handle notifications that are not in the cache
        return;
    }
    if (event === 'click') {
        (_a = notification.onclick) === null || _a === void 0 ? void 0 : _a.call(notification);
    }
    // TODO: handle other events?
}
class DesktopNotification {
    constructor(title, body) {
        this.title = title;
        this.body = body;
        this.id = uuid_1.v4();
    }
    show() {
        shownNotifications.set(this.id, this);
        showNotification(this.id, this.title, this.body);
    }
    close() {
        shownNotifications.del(this.id);
        closeNotification(this.id);
    }
}
exports.DesktopNotification = DesktopNotification;
//# sourceMappingURL=desktop-notifications.js.map